@@ -1,6 +1,6 @@
 ;;; ox-freemind.el --- Freemind Mindmap Back-End for Org Export Engine
 
-;; Copyright (C) 2013  Free Software Foundation, Inc.
+;; Copyright (C) 2013-2016  Free Software Foundation, Inc.
 
 ;; Author: Jambunathan K <kjambunathan at gmail dot com>
 ;; Keywords: outlines, hypermedia, calendar, wp
@@ -312,7 +312,7 @@ will result in following node:
 		   (org-element-property :title element))
 		  (org-data
 		   (plist-get info :title))
-		  (t (error "Shouldn't come here."))))
+		  (t (error "Shouldn't come here"))))
 	 (element-contents (org-element-contents element))
 	 (section (assq 'section element-contents))
 	 (section-contents
@@ -520,7 +520,7 @@ Return output file's name."
   (let* ((extension (concat ".mm" ))
 	 (file (org-export-output-file-name extension subtreep))
 	 (org-export-coding-system 'utf-8))
-    (org-export-to-file 'freemind ,file
+    (org-export-to-file 'freemind file
       async subtreep visible-only body-only ext-plist)))
 
 (provide 'ox-freemind)
